#
# spec file for package nextcloud-desktop
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname  libnextcloudsync
%define sover   0
Name:           nextcloud-desktop
Version:        3.1.3
Release:        lp152.2.6.1
Summary:        Nextcloud desktop synchronisation client
License:        GPL-2.0-or-later AND LGPL-3.0-or-later
Group:          Productivity/Networking/File-Sharing
URL:            https://nextcloud.com/
Source:         https://github.com/nextcloud/desktop/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        sysctl-sync-inotify.conf
# PATCH-FIX-OPENSUSE nextcloud-desktop-fix-rpath.patch sor.alexei@meowr.ru -- Fix RPATH.
Patch0:         nextcloud-desktop-fix-rpath.patch
# PATCH-FIX-OPENSUSE nextcloud-desktop-remove-datetime.patch sor.alexei@meowr.ru -- Remove __TIME__ and __DATE__.
Patch1:         nextcloud-desktop-remove-datetime.patch
BuildRequires:  AppStream
BuildRequires:  cmake >= 3.2
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  gobject-introspection-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libqt5-linguist-devel
BuildRequires:  pkgconfig
BuildRequires:  qtkeychain-qt5-devel
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(Qt5Keychain)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core) >= 5.12
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5QuickControls2)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5WebEngineWidgets)
BuildRequires:  pkgconfig(Qt5WebKitWidgets)
BuildRequires:  pkgconfig(Qt5WebSockets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(cloudproviders)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(openssl) >= 1.1
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(zlib)
Requires:       %{soname}%{sover} = %{version}
Requires:       libqt5-qtgraphicaleffects
Requires:       libqt5-qtquickcontrols2
Provides:       nextcloud-client = %{version}
Obsoletes:      nextcloud-client < %{version}
Provides:       nextcloud-client-lang = %{version}
Obsoletes:      nextcloud-client-lang < %{version}
%if 0%{?is_opensuse}
BuildRequires:  doxygen
BuildRequires:  python3-Sphinx
Suggests:       %{name}-doc = %{version}
%endif

%description
The Nextcloud Desktop Client is a tool to synchronise files from
the Nextcloud Server with your computer.

Nextcloud Desktop enables you to connect to your private
Nextcloud Server. With it you can create directories in your home
directory, and keep the contents of those directories synced with
the server. Simply copy a file into the directory and the desktop
synchronisation client does the rest.

%lang_package

%if 0%{?is_opensuse}
%package doc
Summary:        Documentation for nextcloud-desktop
Group:          Productivity/Networking/File-Sharing
Provides:       nextcloud-client-doc = %{version}
Obsoletes:      nextcloud-client-doc < %{version}
BuildArch:      noarch

%description doc
The Nextcloud Desktop Client is a tool to synchronise files from
the Nextcloud Server with your computer.

This package contains the documentation.
%endif

%package -n %{soname}%{sover}
Summary:        The Nextcloud synchronisation library
Group:          Productivity/Networking/File-Sharing

%description -n %{soname}%{sover}
The Nextcloud Desktop Client synchronisation library.

%package -n %{soname}-devel
Summary:        Development files for the Nextcloud synchronisation library
Group:          Development/Libraries/C and C++
Requires:       %{soname}%{sover} = %{version}

%description -n %{soname}-devel
Development files for the Nextcloud Desktop Client synchronisation
library.

%package -n nautilus-extension-nextcloud
Summary:        Nautilus overlay icons
Group:          Productivity/Networking/File-Sharing
Requires:       %{name} = %{version}
Requires:       nautilus
Requires:       python3-nautilus
Supplements:    (%{name} and nautilus)
BuildArch:      noarch

%description -n nautilus-extension-nextcloud
This package provides overlay icons to visualise the
synchronisation state in the Nautilus file manager.

%if 0%{?is_opensuse}
%package -n caja-extension-nextcloud
Summary:        Caja overlay icons
Group:          Productivity/Networking/File-Sharing
Requires:       %{name} = %{version}
Requires:       caja
Requires:       python-caja
Supplements:    (%{name} and caja)
BuildArch:      noarch

%description -n caja-extension-nextcloud
This package provides overlay icons to visualise the
synchronisation state in the Caja file manager.

%package -n nemo-extension-nextcloud
Summary:        Nemo overlay icons
Group:          Productivity/Networking/File-Sharing
Requires:       %{name} = %{version}
Requires:       nemo
Requires:       python-nemo
Supplements:    (%{name} and nemo)
BuildArch:      noarch

%description -n nemo-extension-nextcloud
This package provides overlay icons to visualise the
synchronisation state in the Nemo file manager.

%package -n %{name}-dolphin
Summary:        Dolphin overlay icons
Group:          Productivity/Networking/File-Sharing
Requires:       %{name} = %{version}
Requires:       dolphin
Supplements:    (%{name} and dolphin)

%description -n %{name}-dolphin
This package provides the necessary plugin libraries for the
Dolphin filemanager to display overlay icons.
%endif

%prep
%setup -q -n desktop-%{version}
%patch0 -p1
%patch1 -p1
cp -a %{SOURCE1} sysctl-sync-inotify.conf

%build
%cmake \
%if 0%{?is_opensuse}
  -DWITH_DOC=ON          \
  -DNO_SHIBBOLETH=1 \
%endif
  -DCMAKE_SKIP_RPATH=OFF
%cmake_build

%install
%cmake_install

%if 0%{?is_opensuse}
mkdir -p %{buildroot}%{_docdir}/%{name}-doc/
mv -f %{buildroot}%{_datadir}/doc/client/nextcloud-client/html/ \
  %{buildroot}%{_docdir}/%{name}-doc/html/
%else
# There's no Caja and Nemo in SLE.
rm -r %{buildroot}%{_datadir}/caja-python/
rm -r %{buildroot}%{_datadir}/nemo-python/
%endif

# Generate bytecode for extensions.
for fm in caja nautilus nemo; do
    if [ -d %{buildroot}%{_datadir}/$fm-python/ ]; then
        %py3_compile %{buildroot}%{_datadir}/$fm-python/extensions/
    fi
done

# ecsos: Comment this out, because it seems to be a security risk.
# See: https://github.com/owncloud/client/issues/4107#issuecomment-240627858
# A workaround for gh#owncloud/client#4107
#install -Dpm 0644 sysctl-sync-inotify.conf \
#  %%{buildroot}%%{_sysconfdir}/sysctl.d/99-%%{name}-sync-inotify.conf

%suse_update_desktop_file com.nextcloud.desktopclient.nextcloud
%fdupes %{buildroot}%{_datadir}/

%post -n %{soname}%{sover} -p /sbin/ldconfig

%postun -n %{soname}%{sover} -p /sbin/ldconfig

%files
%license COPYING*
%config %{_sysconfdir}/Nextcloud/
#%%config %%{_sysconfdir}/sysctl.d/99-%%{name}-sync-inotify.conf
%{_bindir}/nextcloud*
%dir %{_datadir}/nextcloud/
%{_datadir}/applications/com.nextcloud.desktopclient.nextcloud.desktop
%dir %{_datadir}/icons/hicolor/1024x1024/
%dir %{_datadir}/icons/hicolor/1024x1024/apps/
%{_datadir}/icons/hicolor/*/apps/Nextcloud*.*
%dir %{_datadir}/cloud-providers/
%{_datadir}/cloud-providers/com.nextcloudgmbh.Nextcloud.ini
%{_datadir}/dbus-1/services/com.nextcloudgmbh.Nextcloud.service

%files lang
%{_datadir}/nextcloud/i18n/

%if 0%{?is_opensuse}
%files doc
%doc %{_docdir}/%{name}-doc/
%endif

%files -n %{soname}%{sover}
%license COPYING*
%{_libdir}/%{soname}.so.*
%dir %{_libdir}/nextcloud/
%{_libdir}/nextcloud/libocsync.so.*

%files -n %{soname}-devel
%{_includedir}/nextcloudsync/
%{_libdir}/%{soname}.so
%{_libdir}/nextcloud/libocsync.so

%files -n nautilus-extension-nextcloud
%dir %{_datadir}/nautilus-python/
%dir %{_datadir}/nautilus-python/extensions/
%dir %{_datadir}/nautilus-python/extensions/__pycache__
%{_datadir}/nautilus-python/extensions/syncstate-Nextcloud.py*
%{_datadir}/nautilus-python/extensions/__pycache__/syncstate-Nextcloud*

%if 0%{?is_opensuse}
%files -n caja-extension-nextcloud
%dir %{_datadir}/caja-python/
%dir %{_datadir}/caja-python/extensions/
%dir %{_datadir}/caja-python/extensions/__pycache__
%{_datadir}/caja-python/extensions/syncstate-Nextcloud.py*
%{_datadir}/caja-python/extensions/__pycache__/*

%files -n nemo-extension-nextcloud
%dir %{_datadir}/nemo-python/
%dir %{_datadir}/nemo-python/extensions/
%dir %{_datadir}/nemo-python/extensions/__pycache__
%{_datadir}/nemo-python/extensions/syncstate-Nextcloud.py*
%{_datadir}/nemo-python/extensions/__pycache__/*

%files dolphin
%{_libdir}/libnextclouddolphinpluginhelper.so
%{_libdir}/qt5/plugins/nextclouddolphinactionplugin.so
%dir %{_libdir}/qt5/plugins/kf5/overlayicon/
%{_libdir}/qt5/plugins/kf5/overlayicon/nextclouddolphinoverlayplugin.so
%{_datadir}/kservices5/nextclouddolphinactionplugin.desktop
%endif

%changelog
* Sat Feb 20 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.1.3:
  - desktop#2884 [stable-3.1] Add support for Hirsute
  - desktop#2920 [stable-3.1] Validate sensitive URLs to onle allow http(s) schemes.
  - desktop#2926 [stable-3.1] Validate the providers ssl certificate
  - desktop#2939 Bump release to 3.1.3
- This also fix security issues:
  - (boo#1184770, CVE-2021-22879, NC-SA-2021-008 , CWE-99)
    Nextcloud Desktop Client prior to 3.1.3 is vulnerable to resource
    injection by way of missing validation of URLs, allowing a
    malicious server to execute remote commands.
    User interaction is needed for exploitation.
* Thu Jan 28 2021 ecsos <ecsos@opensuse.org>
- Update to 3.1.2
  - desktop#2846 [stable-3.1] Handle SVG branded clients
  - desktop#2849 [stable-3.1] Default to colored systray on linux
  - desktop#2866 [stable-3.1] Add push notifications for file changes
  - desktop#2871 [stable-3.1] Start file conflict resolve dialog asynchronous
  - desktop#2878 [stable-3.1] Use push notifications for Tray activities/notifications fetch trigger.
  - desktop#2880 Bump release to 3.1.2
* Wed Dec 23 2020 ecsos <ecsos@opensuse.org>
- Update to 3.1.1
  - desktop#2709 [stable-3.1] Have the new account wizard open again
  - desktop#2715 [stable-3.1] UserModel: check indices are inside the user list
  - desktop#2716 [stable-3.1] Use the icon color property to color the icons in the tray window header.
  - desktop#2717 [stable-3.1] Ensure a sync happens after a conflict resolution
  - desktop#2730 [stable-3.1] Make monochrome icons the default on Linux and Mac OS.
  - desktop#2753 [stable-3.1] Fixed the autostart for AppImages. See #2504.
  - desktop#2761 Bump release to 3.1.1
* Mon Dec 14 2020 ecsos <ecsos@opensuse.org>
- Update to 3.1.0
  - desktop#2221 Make QML code more declarative by using properties
  - desktop#2497 MacOS: Fix memory leak in FolderWatcherPrivate::startWatching
  - desktop#2500 Windows MSI: Update Docs & add SKIPAUTOUPDATE property
  - desktop#2512 Handle redirects when downloading updates
  - desktop#2514 Make it easier for user to provide debug information
  - desktop#2520 Handle ask for optional password capability
  - desktop#2521 Use friendly user agent during authentication
  - desktop#2527 Improve conflict handling gui
  - desktop#2530 Repair the Windows build
  - desktop#2531 Bring back the "Pause sync" action in the systray context menu
  - desktop#2534 Connection wizard improvements
  - desktop#2540 Add last / to exclude list file path.
  - desktop#2541 Don't use nullptr for QFlags
  - desktop#2542 Avoid string translation puzzle
  - desktop#2543 Update bookmarks location
  - desktop#2551 Fix share dialog animation for enforced password policy
  - desktop#2568 Fix crash when clicking on folder with status 403 in the main dialog.
  - desktop#2572 Avoid depth infinity propfind for e2ee
  - desktop#2575 Expose branding values to qtquick
  - desktop#2580 Delay initialization of SettingsDialog
  - desktop#2581 Ensure we quickly show/hide the systray window on startup
  - desktop#2582 Also output the event flags in the debug logs
  - desktop#2586 L10n: Add a space in generalsettings.ui
  - desktop#2587 Triple dot to ellipsis
  - desktop#2589 Misc fixes for Windows 7
  - desktop#2591 Remove last left over of the "remote" wording
  - desktop#2603 Get rid of FindQt5Keychain.cmake
  - desktop#2615 Fetch apps when we get connected only
  - desktop#2616 Move journaldb files back to sync folders
  - desktop#2620 Make sure the settings dialog exist before hiding it
  - desktop#2621 [documentation] upload chunks config
  - desktop#2630 Master is now 3.0.81
  - desktop#2647 Cherry pick updater fixes and improvements
  - desktop#2648 Issue a warning for Debian pipeline failures but don't fail the CI
  - desktop#2652 Handle the case when the release version differs from that in VERSION.cmake
  - desktop#2655 Use dynamic path for account online/offline state icon.
    Refresh GUI on connection state change.
  - desktop#2658 Enable the QML debugger on debug builds
  - desktop#2660 FolderWatcher: fixes and improvements
  - desktop#2662 Fix QML debugging by removing incorrect dependency
  - desktop#2663 Fix Windows compilation broken after QML debugging fix.
  - desktop#2665 Sparkle build fixes
  - desktop#2666 Notification action buttons and context menu
  - desktop#2667 Master is now 3.0.82.
  - desktop#2675 Fix AppImage build
  - desktop#2677 Fix macOS bug where tray window causes spaces to switch
  - desktop#2682 Add debug log to check which folders are being skipped during syncing.
  - desktop#2685 Fixed slow sharee search in the share dialog
  - desktop#2686 Added sharing via email.
  - desktop#2690 Update documentation on how to generate debug logs.
  - desktop#2696 Bump master version to 3.1.0
- Rebase nextcloud-desktop-fix-rpath.patch.
* Mon Dec 14 2020 ecsos <ecsos@opensuse.org>
- Update to 3.1.0
  - desktop#2221 Make QML code more declarative by using properties
  - desktop#2497 MacOS: Fix memory leak in FolderWatcherPrivate::startWatching
  - desktop#2500 Windows MSI: Update Docs & add SKIPAUTOUPDATE property
  - desktop#2512 Handle redirects when downloading updates
  - desktop#2514 Make it easier for user to provide debug information
  - desktop#2520 Handle ask for optional password capability
  - desktop#2521 Use friendly user agent during authentication
  - desktop#2527 Improve conflict handling gui
  - desktop#2530 Repair the Windows build
  - desktop#2531 Bring back the "Pause sync" action in the systray context menu
  - desktop#2534 Connection wizard improvements
  - desktop#2540 Add last / to exclude list file path.
  - desktop#2541 Don't use nullptr for QFlags
  - desktop#2542 Avoid string translation puzzle
  - desktop#2543 Update bookmarks location
  - desktop#2551 Fix share dialog animation for enforced password policy
  - desktop#2568 Fix crash when clicking on folder with status 403 in the main dialog.
  - desktop#2572 Avoid depth infinity propfind for e2ee
  - desktop#2575 Expose branding values to qtquick
  - desktop#2580 Delay initialization of SettingsDialog
  - desktop#2581 Ensure we quickly show/hide the systray window on startup
  - desktop#2582 Also output the event flags in the debug logs
  - desktop#2586 L10n: Add a space in generalsettings.ui
  - desktop#2587 Triple dot to ellipsis
  - desktop#2589 Misc fixes for Windows 7
  - desktop#2591 Remove last left over of the "remote" wording
  - desktop#2603 Get rid of FindQt5Keychain.cmake
  - desktop#2615 Fetch apps when we get connected only
  - desktop#2616 Move journaldb files back to sync folders
  - desktop#2620 Make sure the settings dialog exist before hiding it
  - desktop#2621 [documentation] upload chunks config
  - desktop#2630 Master is now 3.0.81
  - desktop#2647 Cherry pick updater fixes and improvements
  - desktop#2648 Issue a warning for Debian pipeline failures but don't fail the CI
  - desktop#2652 Handle the case when the release version differs from that in VERSION.cmake
  - desktop#2655 Use dynamic path for account online/offline state icon.
    Refresh GUI on connection state change.
  - desktop#2658 Enable the QML debugger on debug builds
  - desktop#2660 FolderWatcher: fixes and improvements
  - desktop#2662 Fix QML debugging by removing incorrect dependency
  - desktop#2663 Fix Windows compilation broken after QML debugging fix.
  - desktop#2665 Sparkle build fixes
  - desktop#2666 Notification action buttons and context menu
  - desktop#2667 Master is now 3.0.82.
  - desktop#2675 Fix AppImage build
  - desktop#2677 Fix macOS bug where tray window causes spaces to switch
  - desktop#2682 Add debug log to check which folders are being skipped during syncing.
  - desktop#2685 Fixed slow sharee search in the share dialog
  - desktop#2686 Added sharing via email.
  - desktop#2690 Update documentation on how to generate debug logs.
  - desktop#2696 Bump master version to 3.1.0
* Sat Oct 31 2020 ecsos <ecsos@opensuse.org>
- Update to 3.0.3
  - desktop#2479 [stable-3.0] Free IconJob after use
  - desktop#2491 [stable-3.0] Connect signal guiLog to slot to display systray message.
  - desktop#2498 [stable-3.0] Update propagateupload.cpp
  - desktop#2502 [stable-3.0] macOS: Fix memory leak in FolderWatcherPrivate::startWatching
  - desktop#2511 [stable-3.0] Windows MSI: Update Docs & add SKIPAUTOUPDATE property
  - desktop#2513 [stable-3.0] Handle redirects when downloading updates
  - desktop#2524 [stable-3.0] Handle ask for optional password capability
  - desktop#2533 [stable-3.0] Repair the Windows build
  - desktop#2567 [stable-3.0] Fix share dialog animation for enforced password policy
  - desktop#2570 [stable-3.0] Fix crash when clicking on folder with status 403 in
    the main dialog.
  - desktop#2576 [stable-3.0] Avoid depth infinity propfind for e2ee
  - desktop#2577 [stable-3.0] Expose branding values to qtquick
  - desktop#2592 [stable-3.0] Also output the event flags in the debug logs
* Tue Oct 27 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Add missing dependencies (boo#1178209)
* Thu Sep 24 2020 ecsos <ecsos@opensuse.org>
- Update to 3.0.2
  - desktop#2346 Use httpd/unix-directory mimetype for E2EE folders
  - desktop#2388 Update copyright date and version displayed in the page title.
  - desktop#2415 syncjournaldb: index e2eMangledName column in metadata
  - desktop#2421 Use QGuiApplication::primaryScreen() as fallback for Systray::currentScreen()
  - desktop#2422 Fix menu popup in main dialog
  - desktop#2426 Include list info in tooltip
  - desktop#2428 Try to enable the CI on stable branches as well
  - desktop#2429 Improve drone config
  - desktop#2430 Fix clang tidy errors in csync tests
  - desktop#2434 Windows: Fix NSIS language encoding (use UTF-8)
  - desktop#2436 Fix incomplete journal upgrade from 2.x to 3.x
  - desktop#2448 If there's no description just say nothing
  - desktop#2455 Remove "This includes" due to tooltip order
  - desktop#2456 Fix missing subdirectory discovery on move operations in macOS
  - desktop#2458 Windows: MSI support & Win32 migration tools
  - desktop#2463 Use native text rendering for qml windows
  - desktop#2465 Allow server URL to be pre-defined without enforcing it
  - desktop#2471 Force tooltip wrap mode because it's not enabled in Qt 5.12...
* Thu Sep 24 2020 ecsos <ecsos@opensuse.org>
- Update to 3.0.2
  - desktop#2346 [stable-3.0] Use httpd/unix-directory mimetype for E2EE folders
  - desktop#2388 [stable-3.0] Update copyright date and version displayed in the page title.
  - desktop#2415 [stable-3.0] syncjournaldb: index e2eMangledName column in metadata
  - desktop#2421 [stable-3.0] Use QGuiApplication::primaryScreen() as fallback for Systray::currentScreen()
  - desktop#2422 [stable-3.0] Fix menu popup in main dialog
  - desktop#2426 [stable-3.0] Include list info in tooltip
  - desktop#2428 [stable-3.0] Try to enable the CI on stable branches as well
  - desktop#2429 [stable-3.0] Improve drone config
  - desktop#2430 [stable-3.0] Fix clang tidy errors in csync tests
  - desktop#2434 [stable-3.0] Windows: Fix NSIS language encoding (use UTF-8)
  - desktop#2436 [stable-3.0] Fix incomplete journal upgrade from 2.x to 3.x
  - desktop#2448 [stable-3.0] If there's no description just say nothing
  - desktop#2455 [stable-3.0] Remove "This includes" due to tooltip order
  - desktop#2456 [stable-3.0] Fix missing subdirectory discovery on move operations in macOS
  - desktop#2458 [stable-3.0] Windows: MSI support & Win32 migration tools
  - desktop#2463 [stable-3.0] Use native text rendering for qml windows
  - desktop#2465 [stable-3.0] Allow server URL to be pre-defined without enforcing it
  - desktop#2471 [stable-3.0] Force tooltip wrap mode because it's not enabled in Qt 5.12...
* Fri Aug 28 2020 ecsos <ecsos@opensuse.org>
- Update to 3.0.1
  - desktop#2300 Support client builds on VS2019 (QLinkedList is deprecated)
  - desktop#2302 Do not build for Eoan
  - desktop#2288 Windows shell extensions: Use custom GUIDs via CMake and prepare MSI reg
  - desktop#2292 Present sharing of E2EE files from the main dialog too
  - desktop#2292 Disable context menu actions for E2EE files and folders
  - desktop#2281 Show the "Display mnemonic" button only when we know e2e is supported
  - desktop#2278 Make sure we don't assert when calling fileStatus
- Enable libcloudprovider again.
* Fri Aug 21 2020 Mathias Homann <Mathias.Homann@opensuse.org>
- Update to 3.0.0
  - #1886 Move the proxyfiles to libsync where they make more sense
  - #1939 Major multi monitor improvements and rewrite of tray window positioning
  - #2093 Add photothumb.db to sync-exclude.lst
  - #2099 Ease access to main dialog
  - #2106 Fix libsync exports for proxy changes in #1886
  - #2110 Darken menu border color
  - #2119 Fix SEGV (due to circular ownership) at exit
  - #2126 Slightly simplify code for Systray positioning
  - #2127 ConfigFile security: Migrate Proxy password to keychain
  - #2128 Fix subfolder encryption scheme
  - #2139 Fix e2ee folder sync connection
  - #2144 Fix e2ee upload lock starvation
  - #2145 Repair and improve logging
  - #2150 Fix e2e moves handling
  - #2159 Reach out to the contentItem inside of the ListView to find the width
  - #2167 Fix url decoding for folder encryption status
  - #2168 Display the correct default permissions when creating a share.
  - #2177 Share link display the correct permissions for files and folders.
  - #2183 Prevent empty FileMap in local csync to be processed if folder not empty
  - #2188 Move existing syncjournal db files from client ver <2.7
  - #2201 Disable parallelism for e2e remote mkdir jobs
  - #2209 Fix pause sync states
  - #2211 Logo update for 2.7
  - #2213 Drone: Upload AppImage to GitHub using nextcloud-desktop-bot
  - #2215 Change ownCloud reference to Nextcloud
  - #2224 Update CI for Qt 5.12.9
  - #2227 Support png for branded clients systray
  - #2245 Fix #2243
  - #2248 There won't be a 2.7, this is called 3.0 instead
  - #2257 [stable-3.0] Restore E2EE old key storage format compatibility
  - #2259 [stable-3.0] Keep the E2EE info message around to allow displaying mnemonic
* Thu Jul  9 2020 ecsos <ecsos@opensuse.org>
- Update to 2.6.5
  - #1449 Linux/Wayland: Updated .desktop file naming scheme
  - #1834 Use print() function in both Python 2 and Python 3
  - #1835 Added build for Focal
  - #1838 Allow sharing to circles
  - #1839 Added Focal-specific files
  - #1841 Allow sharing to circles
  - #1843 Enhance Version info display (minimal info, hide details)
  - #1847 Updater: Enhance UI, make build optional
  - #1848 WebView: Add missing Q_OBJECT macros
  - #1851 Enhance Version info display (minimal info, hide details)
  - #1853 Updater: Fix Tests build (failed with BUILD_UPDATER=NO)
  - #1854 Updater: Fix Tests build (failed with BUILD_UPDATER=NO)
  - #1855 WebView: Add missing Q_OBJECT macros
  - #1859 Provide specific install file for Debian oldstable
  - #1879 Add desktop-entry hint to notifications
  - #1880 Remove timeout parameter from showMessage
  - #1881 Use qEnvironmentVariableIsEmpty
  - #1882 Fix container detaching
  - #1883 [dolphin] Add icon to context menu
  - #1886 Move the proxyfiles to libsync where they make more sense
  - #1909 Fix build with Qt 5.15
  - #1931 Fix container detaching
  - #1932 [dolphin] Add icon to context menu
  - #1933 Fix build of Dolphin integration
  - #1934 Fix build of Dolphin integration
  - #1954 Fix typos.
  - #1956 Update ChangeLog with 2.6 series.
  - #1958 Resolve symlinks when checking for registered paths.
  - #1972 Fix leak in FileUtil::IsChildFile
  - #1973 Fix leak in FileUtil::IsChildFile
  - #1974 Don't silently kill debug messages
  - #1975 Don't silently kill debug messages
  - #1986 Properly handle denormalized href
  - #1987 Fix a few leaks
  - #1988 Use nullptr when appropriate
  - #1989 Remove useless virtual, better use override only
  - #1991 Improve sanitizer support
  - #1992 Update github links to desktop repository
  - #1996 Properly handle denormalized href
  - #1997 Use nullptr when appropriate
  - #1998 Update github links to desktop repository
  - #1999 Remove useless virtual, better use override only
  - #2000 Don't use int literals for bools
  - #2001 Use default member initialization
  - #2005 Use default member initialization
  - #2006 Improve URL input field in Wizard
  - #2007 Improve URL input field in Wizard
  - #2017 Remove redundant initializer
  - #2018 Use using instead of typedef
  - #2019 Remove redundant void argument list
  - #2020 Use make_unique when appropriate
  - #2021 Use = default for trivial ctors and dtors
  - #2023 Use the return braced init list pattern
  - #2024 Use raw string literals when appropriate
  - #2025 Remove redundant initializer
  - #2026 Use using instead of typedef
  - #2027 Remove redundant void argument list
  - #2028 Use make_unique when appropriate
  - #2029 Use = default for trivial ctors and dtors
  - #2032 TestLaunchOnStartup shouldn't fail on dev setup
  - #2033 Use the return braced init list pattern
  - #2034 testLaunchOnStartup shouldn't fail on dev setup
  - #2051 Remove Submodule binary (old upstream binaries)
  - #2052 Remove Submodule binary (old upstream binaries)
  - #2061 Improve command line version info and help display (gui & cmd)
  - #2062 Improve command line version info and help display (gui & cmd)
  - #2063 MacOS: Opt In to Dark Mode for building against older macOS SDKs < 10.14
  - #2064 macOS: Opt In to Dark Mode for building against older macOS SDKs < 10.14
  - #2065 Use APPLICATION_ICON_NAME for autostart icon
  - #2068 Don't show a message box if the entered url returned an error
  - #2069 Use APPLICATION_ICON_NAME for autostart icon
  - #2071 Linux/Wayland: Updated .desktop file naming scheme
  - #2072 AppImage: Upgrade to Qt 5.12.8
  - #2078 Replace NULL by nullptr in all C++ files
  - #2083 Simplify nullptr comparisons where appropriate
  - #2084 macOS: Use macdeployqt instead of the old admin/osx/macdeployqt.py
  - #2093 Add photothumb.db to sync-exclude.lst
  - #2106 Fix libsync exports for proxy changes in #1886
  - #2109 Default system proxy not working with Account Wizard (fixes #2108)
  - #2127 ConfigFile security: Migrate Proxy password to keychain
  - #2147 Repair and improve logging
  - #2152 Don't display quota information when the user has no quota.
  - #2162 ConfigFile security: Migrate Proxy password to keychain
  - #2168 Display the correct default permissions when creating a share.
  - #2170 [stable 2.6] Asemmar/issue 2137
  - #2177 Share link display the correct permissions for files and folders.
  - #2179 Display the correct default permissions when creating a share.
- Drop nextcloud-desktop-qt_5.15.patch because now in upstream.
* Mon Jun  8 2020 ecsos <ecsos@opensuse.org>
- Fix build error in Tumbleweed.
  - Add nextcloud-desktop-qt_5.15.patch to fix build error with
    Qt 5.15.
* Sun Mar  8 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Rename nextcloud-client to nextcloud-desktop following upstream.
- Stop redundantly recommending the -lang package.
* Wed Mar  4 2020 ecsos@opensuse.org
- Update to 2.6.4
  * Fix Explorer pinning: Add fallbacks for Shell commands
    (gh#nextcloud/desktop#1599).
  * WebFlowCredentials: Make username comparison case-insensitive
    (gh#nextcloud/desktop#1741).
  * ActivityListModel: Show full date and time as a Tooltip only.
  * Disable HTTP/2 for now due to a Qt bug, allow enabling it via
    an environment variable.
  * Fix Explorer integration re-save and hide option.
  * l10n: Changes to improve source strings.
  * Updater: Add query-parameter "updatesegment" to the update
    check.
* Mon Feb 17 2020 ecsos@opensuse.org
- Update to 2.6.3
  - desktop#1782 Add UserInfo class and fetch quota via API instead
    of PropfindJob
  - desktop#1770 l10n: Changed grammar and triple dots to ellipsis
  - desktop#1767 l10n: Changed spelling of user name to username
  - desktop#1765 Start the client in background if activated
    by D-Bus
  - desktop#1764 Do not install files related to cloud providers
    under Xenial
  - desktop#1763 Make sure that the libcloudprovider integration is
    using a valid D-Bus path
  - desktop#1762 Changed product name to Nextcloud
  - desktop#1760 Update autoupdate.rst
  - desktop#1745 Use system proxy by default if no config file is
    present
  - desktop#1729 Install libcloudproviders files by default on
    debian
  - desktop#1727 Windows 7 is out of support
  - desktop#1721 BugFix: Handle broken shared file error gracefully
  - desktop#1720 Fix Explorer integration on Windows and the crash
    on other systems
  - desktop#1718 Welcome to 2020
  - desktop#1707 Updated year in legalnotice.cpp
  - desktop#1699 apply http2 qt resend patch from owncloud
- Run spec-cleaner.
* Wed Dec 25 2019 ecsos@opensuse.org
- Update to 2.6.2
  - desktop#1456 Revert DEFAULT_REMOTE_POLL_INTERVAL back from 5
    seconds to 30 seconds
  - desktop#1459 Use user-provided username in displayName() -
    Fix #836
  - desktop#1462 Fix typo
  - desktop#1471 Build with libcloudproviders on debian and in the
    AppImage
  - desktop#1487 Fix tests for Windows platform
  - desktop#1523 Merge the list of ignored files/symlinks into one
    Activity notification.
  - desktop#1526 Fix clang's variadic macro warnings
  - desktop#1531 Add libdbus-1-dev to the build dependencies
  - desktop#1593 Compare QDateTime objects more efficient
  - desktop#1611 Improve the translation of "Share via …"
  - desktop#1617 Upgrade for Qt 5.12.5 in docker-ci
  - desktop#1619 Bump Qt 5.12.5 image
  - desktop#1621 Add timestamp to Mac installer code signing
  - desktop#1623 MacOS build: Avoid the Get-Task-Allow Entitlement
    (Notarization)
  - desktop#1629 Build for Debian stable and oldstable
  - desktop#1641 Happy new year
  - desktop#1644 Fall back to old login flow on GS as this is not
    yet ready
  - desktop#1645 [stable-2.6] macOS build: Avoid the Get-Task-Allow
    Entitlement (Notarization)
  - desktop#1646 Fix remote wipe keychain storage (issue #1592)
  - desktop#1647 Fix copyright year in MacOSXBundleInfo.plist.in
    for 2019
  - desktop#1651 Fix macOS GUI (Qt 5.12)
  - desktop#1664 Windows: Workaround for storing >= 4k (4096 bit)
    client-cert SSL keys
* Fri Nov  8 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Rename 100-nextcloud-client-sync-inotify.conf to
  99-nextcloud-client-sync-inotify.conf (boo#1155457).
* Tue Nov  5 2019 ecsos@opensuse.org
- Update to 2.6.1
  - desktop#1032 Changed max GUI bandwidth limits
  - desktop#1039 Add sync date next to "Synchronized with local
    folder"
  - desktop#1149 Slideshow buttons
  - desktop#1214 Fix qt warning about registering a URL sheme first.
  - desktop#1231 Issue #1216: added sync-exclude entry for emacs
    recovery files
  - desktop#1240 Race condition in the remote size loading logic
  - desktop#1409 Review of msvc/gcc warnings -> code cleanup,
    prevention of implicit casts, variadic macros
  - desktop#1414 Fix double slashes
  - desktop#1420 Fixing E2E CSR transmission failure for new
    connections
  - desktop#1441 Fixed missing 'translatable' exclusions, added
    missing window titles
  - desktop#1461 Checks if exclude file is empty before creating
    the regular expressions.
  - desktop#1465 Add server info to menu
  - desktop#1474 Fixed grammar
  - desktop#1477 Prevent jumping of tray menu
  - desktop#1478 Don't run connection wizard when quitting the
    application
  - desktop#1481 Avoiding copying in range-based loops
  - desktop#1495 Add a 'Content-Length: 0' header to initial POST
    requests
  - desktop#1504 Remote wipe.
  - desktop#1520 Pick from upstream: Update qtmacgoodies for an OSX
    crash fix #6930
  - desktop#1522 * fix for issue no. #1351
  - desktop#1523 Merge the list of ignored files/symlinks into one
    Activity notification.
  - desktop#1527 Update submodules for Qt 5.12.5 (qtmacgoodies)
  - desktop#1554 Fix duplicate items in Apps menu
    (a bug introduced in #1477)
  - desktop#1573 Fix #1182
  - desktop#1579 Fix remote wipe when a proxy is configured.
  - desktop#1580 Fix updater message: Download link instead of
    "use the system's update
* Thu Oct 10 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Do not BuildRequire python: this is python2, but in other places
  we buildrequire python3-Sphinx. This does not really belong
  together.
- Switch the python-nautilus Requires in
  nautilus-extension-nextcloud to be python3-nautilus: the plugin
  supports py3 already, so best to make use of it.
* Fri Sep 27 2019 Mathias Homann <Mathias.Homann@opensuse.org>
- Update to 2.6.0
  * desktop#1222 Reinstate Debian build in the new Drone config
  * desktop#1225 Typo
  * desktop#1256 Marking unused strings as unstranslatable
  * desktop#1275 Fixes #607
  * desktop#1278 Fixes issue #878
  * desktop#1342 Fixes issue #1187
  * desktop#1347 Displays FileIgnored activities with an info icon
  * desktop#1354 Minor text change in the link to help in the tab 'General'.
  * desktop#1359 Update Qt 5.5 compatibility patch for Xenial
  * desktop#1360 Remove Ubuntu Cosmic and add Eoan package
  * desktop#1366 Add proper CA to client side certificate connection
  * desktop#1372 Remove dependency on libgnome-keyring0 on Eoan
  * desktop#1374 Read .sync_exclude.lst in each subdirectory
  * desktop#1376 Updates ChangeLog.
  * desktop#1384 Login flow v2
  * desktop#1389 Adds SSL client cert storage to webflow + Login Flow v2
  * desktop#1394 Windows: Workaround for CredWriteW used by QtKeychain
  * desktop#1399 Integrated registry check on windows when hasDarkSystray is called.
  * desktop#1401 Logo update
  * desktop#1402 Updated .gitignore to integrate unwanted files when working with VSC …
  * desktop#1405 Full-Scaled new logo in Windows 10 start menu tile
  * desktop#1408 Qt5.5 compatiblity patch for login flow V2 + UI improvement (Use newer digest algorithms in TLS error dialog)
  * desktop#1427 Fix for #1382 "linux client crashes for no discernable reason"
  * desktop#1434 UI improvement: Message box: Delete / Keep all files
  * desktop#1443 Improve wording of the context menu in the file manager extension.
  * desktop#1447 Changes wording in the share context menu.
  * Fix White Window issue on Windows by upgrading to Qt 5.12.5
* Mon Jul 22 2019 ecsos@opensuse.org
- Update to 2.5.3
  - desktop#1118 Fix empty file wording in error log (small)
  - desktop#1153 Add Qt-5.12 to CI
  - desktop#1157 Fix a minor typo
  - desktop#1185 Libcloudproviders: Add missing check for Qt5DBus
  - desktop#1186 Fix several memory leaks in cloudproviders and add
    translation support
  - desktop#1191 Share link fixing
  - desktop#1200 New drone config
  - desktop#1201 Uses configuraion to determine if it should show
    empty folder popup.
  - desktop#1212 Simplify cmake command to make copy-pastable
  - desktop#1234 Updated default remote poll to 5 seconds #1115
  - desktop#1239 Fix memory leak with device pointer
  - desktop#1241 Added a nice UI for the E2E-enabled account first
    connect
  - desktop#1245 This should fix issue #1000
  - desktop#1247 Adds parameter to retrieve shares with its
    reshares.
  - desktop#1251 Fixed typo
  - desktop#1253 Fixed typo in "certificate"
  - desktop#1273 WebView: Properly handle usernames with spaces and
    plus signs in it
  - desktop#1301 Add error category for http file lock error status
    423.
  - desktop#1309 Displays the uid_owner of a shared file.
* Tue Apr 30 2019 Bjoern Voigt <bjoernv@arcor.de>
- Update to version 2.5.2
  * desktop#1001 Handle spaces in username properly in login flow
  * desktop#1006 Wizard: show an error message if there is no enough free space in the local folder
  * desktop#1050 Removed whitespace from string
  * desktop#1054 Do not add double slash to login flow url
  * desktop#1057 Fix login flow with system proxy
  * desktop#1060 Start with easier theming
  * desktop#1062 Do not display dismissed notifications
  * desktop#1069 Fixed l18n issue. Added space for separating string
  * desktop#1071 Add invalid certiticate messagebox
  * desktop#1087 Correct app passwords link
  * desktop#1092 Be less verbose with logging
  * desktop#1119 Fix typo in translation string
  * desktop#778 Add a command line option to launch the client in the background
  * desktop#923 Support Ubuntu Disco Dingo
  * desktop#946 Added missing Include
  * desktop#959 Make sure _profile and _page are deleted in the correct order
  * desktop#981 Fix KDEInstallDirs deprecation warnings
  * desktop#993 Removed Stylesheet
- Removed nextcloud-client-fix-qt-5.12.patch
* Tue Jan 15 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Stop building with libcloudproviders (boo#1118327).
* Mon Jan  7 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Append to nextcloud-client-fix-qt-5.12.patch a fix for a
  QtWebEngine crash on Qt 5.12 (commit 09b0055, boo#1120310).
* Wed Jan  2 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Add nextcloud-client-fix-qt-5.12.patch: Fix an error during build
  with Qt 5.12 (commit 1295884).
* Tue Dec  4 2018 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.5.1:
  * See https://github.com/nextcloud/desktop/compare/v2.5.0...v2.5.1
* Wed Nov 14 2018 sor.alexei@meowr.ru
- Update to version 2.5.0:
  * See https://github.com/nextcloud/desktop/compare/57bc791...v2.5.0
- Remove nextcloud-client-2.3.3-fix-qt-5.11.patch,
  nextcloud-client-fix-caja-nemo-appnames.patch: fixed upstream.
- Rebase nextcloud-client-fix-rpath.patch,
  nextcloud-client-remove-datetime.patch.
- Build with libcloudproviders.
- Drop openSUSE Leap 42.3 and older support.
* Tue Jun 12 2018 sor.alexei@meowr.ru
- Add nextcloud-client-2.3.3-fix-qt-5.11.patch: Fix Qt 5.11+
  compatibility.
* Thu Mar  1 2018 ecsos@opensuse.org
- fix build error for Tumbleweed
* Mon Dec 25 2017 sor.alexei@meowr.ru
- Use a better tarball.
* Tue Dec  5 2017 sor.alexei@meowr.ru
- Update to version 2.3.3:
  * Chunking NG: Don't use old chunking on new DAV endpoint
    (gh#owncloud/client#5855).
  * Selective Synch: Skip excluded directories when reading DB,
    don't let them show errors (gh#owncloud/client#5772).
  * Settings: Make the window bigger so the Qt version is always
    visible (gh#owncloud/client#5760).
  * Share links: Show a warning that public link shares are public
    (gh#owncloud/client#5786).
  * Downloads: Re-trigger directory discovery on HTTP 404
    (gh#owncloud/client#5799).
  * Notifications: Propagate "Dismiss" as DELETE to server
    (gh#owncloud/client#5922).
  * SynchJournalDB: Don't use ._ as a filename pattern if that does
    not work because of SMB storage settings
    (gh#owncloud/client#5844)
  * SynchJournalDB: Log reason for sqlite3 opening errors.
  * Stop maintaining Qt 4 support.
  * New synch state icon design.
  * Add a state-information icon.
  * Update the icon patch.
* Fri Jul 21 2017 ecsos@opensuse.org
- update to 2.3.2
  * Fix more crashes (thanks to everyone submitting to our crash
    reporter!)
  * Improve compatibility with server 10.0 (5691, X-OC-Total-Size)
  * Share dialog: UI improvements, Bring to front on tray click
  * owncloudcmd: Align process return value with sync return value
    (3936)
  * Fix disk free check on Windows when opening the local DB
- insert Requires: %%{soname}%%{sover} = %%{version} because lib
  does not up- or downgrade by up- or downgrade from client itself.
* Wed Jun 14 2017 sor.alexei@meowr.ru
- Only enable documentation for openSUSE Leap 14.3 and newer
  (boo#1044061).
* Thu Mar 23 2017 sor.alexei@meowr.ru
- Update to version 2.3.1 (changes since 2.2.4):
  * Decreased memory usage during synchronisation.
  * Overlay icons: Lower CPU usage.
  * Allow to not synchronise the server's external storages by
    default.
  * Switch to the new Nextcloud Server WebDAV endpoint.
  * Chunking NG: New file upload chunking algorithm for
    Nextcloud Server 11.0.
  * Allow to synchronise a directory to multiple different servers
    (filename change from .csync_journal.db to _sync_$HASH.db).
  * Conflicts: Use the local mtime for the conflict file name
    (gh#owncloud/client#5273).
  * Add a "Sync now" menu item.
  * Improve SSL Client certificate support (Show UI, Store keys in
    keychain).
  * Propagator: Upload smaller files in parallel.
  * Sync Engine: Read data-fingerprint property to detect backups
    (gh#owncloud/client#2325).
  * GUI: Show link to create an application password/token for
    synchronising.
  * Share dialogue: Add a "Mail link" button.
  * A Caja file manager plugin.
  * Make the "backup detected" message not triggered in wrong cases.
  * SyncEngine: Fix directory renaming when files are changed
    (gh#owncloud/client#5192)
  * Fix a reconnect bug if status.php intermittently returns wrong
    data (gh#owncloud/client#5188).
  * Improve synchronisation scheduling (gh#owncloud/client#5317).
  * Overlay icons: Improvements in correctnes.
  * Tray menu: Only update on demand to fix GNU/Linux desktop
    integration glitches.
  * Progress: Better time/bandwidth estimations.
  * Network: Follow certain HTTP redirects (gh#owncloud/client#2791).
  * Network: Remove all cookies (including load balancers, etc.)
    when logging out.
  * Discovery thread: Low priority.
  * nextcloudsync.log: Write during propagation.
  * Excludes: Consider files in hidden directories excluded
    (gh#owncloud/client#5163).
  * Allow the synchronised directory to be a symlinked directory.
  * Improve HTTP redirect handling (gh#owncloud/client#5555).
  * Blacklist: Escalate repeated soft error to normal error
    (gh#owncloud/client#5500).
  * Fix the URL for linking to application password generation for
    ownCloud 10.0 (gh#owncloud/client#5605).
  * Shibboleth bugfixes.
  * Fixes with regards to low disc space.
  * A tonne of other bugfixes.
  * Refactorings.
  * Improve documentation.
  * Crash fixes.
- Add nextcloud-client-remove-datetime.patch: Remove __TIME__ and
  __DATE__.
- Rebase and rename nextcloud-client-fix-nemo-appname.patch to
  nextcloud-client-fix-caja-nemo-appnames.patch.
- Remove nextcloud-client-fix-dolphin.patch,
  nextcloud-client-fix-ru-typo.patch,
  nextcloud-client-fix-tray-workaround.patch: fixed upstream.
- Rename 100-sync-inotify.conf to the less conflicting
  100-nextcloud-sync-inotify.conf.
* Fri Feb  3 2017 sor.alexei@meowr.ru
- Add nextcloud-client-fix-dolphin.patch from bruno_friedmann to
  fix the Dolphin plugin.
* Tue Jan 24 2017 sor.alexei@meowr.ru
- Add nextcloud-client-fix-tray-workaround.patch: fix the tray
  workaround (from commit 98efb07 of owncloud-client).
* Fri Sep 30 2016 ecsos@opensuse.org
- Update to version 2.2.4:
  * Dolphin Plugin: Use the Application name for the socket path
    (gh#owncloud/client#5172).
  * SyncEngine: Fix renaming of directories when files are changed
    (gh#owncloud/client#5195).
  * Selective Sync: Fix HTTP request loop and show error in view
    (gh#owncloud/client#5154).
  * ConnectionValidator: Properly handle error in status.php
    request (gh#owncloud/client#5188).
  * Discovery: Set thread priority to low (gh#owncloud/client#5017).
  * ExcludeFiles: Fix when the directory casing is not the same in
    the settings and in the FS.
  * ShareLink: Ensure the password line edit is enabled
    (gh#owncloud/client#5117).
* Fri Aug 26 2016 sor.alexei@meowr.ru
- Initial package.
